/* topbar.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from topbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <atk/atk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gio/gio.h>


#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesDisplayPagePrivate BoxesDisplayPagePrivate;

#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES,
	BOXES_TOPBAR_PAGE_DISPLAY
} BoxesTopbarPage;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesTopbar {
	BoxesUI parent_instance;
	BoxesTopbarPrivate * priv;
	GtkNotebook* notebook;
	gchar* _status;
};

struct _BoxesTopbarClass {
	BoxesUIClass parent_class;
};

struct _BoxesTopbarPrivate {
	ClutterActor* gtk_actor;
	GtkSpinner* spinner;
	GtkButton* search_btn;
	GtkButton* search2_btn;
	GtkButton* select_btn;
	GtkButton* cancel_btn;
	GtkButton* back_btn;
	GtkButton* new_btn;
	GtkMenuButton* selection_menu_button;
	GtkHeaderBar* selection_toolbar;
	GtkHeaderBar* collection_toolbar;
	GtkHeaderBar* display_toolbar;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesDisplayPage {
	GObject parent_instance;
	BoxesDisplayPagePrivate * priv;
	BoxesDisplayToolbar* title_toolbar;
};

struct _BoxesDisplayPageClass {
	GObjectClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_topbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
#define BOXES_TOPBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_TOPBAR, BoxesTopbarPrivate))
enum  {
	BOXES_TOPBAR_DUMMY_PROPERTY,
	BOXES_TOPBAR_ACTOR,
	BOXES_TOPBAR_WIDGET,
	BOXES_TOPBAR_STATUS
};
BoxesTopbar* boxes_topbar_new (void);
BoxesTopbar* boxes_topbar_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
static void boxes_topbar_setup_topbar (BoxesTopbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void __lambda148_ (BoxesTopbar* self);
static void boxes_topbar_update_selection_label (BoxesTopbar* self);
static void ___lambda148__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda28_ (BoxesTopbar* self, GtkButton* button);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda28__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda29_ (BoxesTopbar* self, GtkButton* button);
static void ___lambda29__gtk_button_clicked (GtkButton* _sender, gpointer self);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void __lambda145_ (BoxesTopbar* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static void ___lambda145__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda146_ (BoxesTopbar* self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
static void ___lambda146__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_topbar_update_select_btn (BoxesTopbar* self);
static void _boxes_topbar_update_select_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_topbar_update_select_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void __lambda147_ (BoxesTopbar* self);
static void ___lambda147__gtk_button_clicked (GtkButton* _sender, gpointer self);
GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
static void boxes_topbar_update_search_btn (BoxesTopbar* self);
static void _boxes_topbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_topbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
GList* boxes_app_get_selected_items (BoxesApp* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_topbar_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GtkWidget* boxes_topbar_get_widget (BoxesTopbar* self);
const gchar* boxes_topbar_get_status (BoxesTopbar* self);
void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value);
static void boxes_topbar_finalize (GObject* obj);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_topbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_topbar_page_get_type (void) {
	static volatile gsize boxes_topbar_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_TOPBAR_PAGE_COLLECTION, "BOXES_TOPBAR_PAGE_COLLECTION", "collection"}, {BOXES_TOPBAR_PAGE_SELECTION, "BOXES_TOPBAR_PAGE_SELECTION", "selection"}, {BOXES_TOPBAR_PAGE_WIZARD, "BOXES_TOPBAR_PAGE_WIZARD", "wizard"}, {BOXES_TOPBAR_PAGE_PROPERTIES, "BOXES_TOPBAR_PAGE_PROPERTIES", "properties"}, {BOXES_TOPBAR_PAGE_DISPLAY, "BOXES_TOPBAR_PAGE_DISPLAY", "display"}, {0, NULL, NULL}};
		GType boxes_topbar_page_type_id;
		boxes_topbar_page_type_id = g_enum_register_static ("BoxesTopbarPage", values);
		g_once_init_leave (&boxes_topbar_page_type_id__volatile, boxes_topbar_page_type_id);
	}
	return boxes_topbar_page_type_id__volatile;
}


static void __lambda148_ (BoxesTopbar* self) {
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_selection_label (self);
#line 405 "topbar.c"
}


static void ___lambda148__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	__lambda148_ (self);
#line 412 "topbar.c"
}


BoxesTopbar* boxes_topbar_construct (GType object_type) {
	BoxesTopbar * self = NULL;
	BoxesApp* _tmp0_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) boxes_ui_construct (object_type);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_setup_topbar (self);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) _tmp0_, "notify::selected-items", (GCallback) ___lambda148__g_object_notify, self, 0);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	return self;
#line 429 "topbar.c"
}


BoxesTopbar* boxes_topbar_new (void) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	return boxes_topbar_construct (BOXES_TYPE_TOPBAR);
#line 436 "topbar.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 443 "topbar.c"
}


static void __lambda28_ (BoxesTopbar* self, GtkButton* button) {
	BoxesApp* _tmp0_ = NULL;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (button != NULL);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 455 "topbar.c"
}


static void ___lambda28__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	__lambda28_ (self, _sender);
#line 462 "topbar.c"
}


static void __lambda29_ (BoxesTopbar* self, GtkButton* button) {
	BoxesApp* _tmp0_ = NULL;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (button != NULL);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 474 "topbar.c"
}


static void ___lambda29__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	__lambda29_ (self, _sender);
#line 481 "topbar.c"
}


static void __lambda145_ (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_app_set_selection_mode (_tmp0_, TRUE);
#line 491 "topbar.c"
}


static void ___lambda145__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	__lambda145_ (self);
#line 498 "topbar.c"
}


static void __lambda146_ (BoxesTopbar* self) {
	gint _tmp0_ = 0;
	BoxesApp* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GtkNotebook* _tmp5_ = NULL;
	gint _tmp6_ = 0;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = boxes_app_get_selection_mode (_tmp1_);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp3_) {
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp0_ = (gint) BOXES_TOPBAR_PAGE_SELECTION;
#line 519 "topbar.c"
	} else {
		GtkNotebook* _tmp4_ = NULL;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp4_ = self->notebook;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_object_set (_tmp4_, "page", (gint) BOXES_TOPBAR_PAGE_COLLECTION, NULL);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp0_ = (gint) BOXES_TOPBAR_PAGE_COLLECTION;
#line 528 "topbar.c"
	}
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = self->notebook;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = _tmp0_;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_set (_tmp5_, "page", _tmp6_, NULL);
#line 536 "topbar.c"
}


static void ___lambda146__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	__lambda146_ (self);
#line 543 "topbar.c"
}


static void _boxes_topbar_update_select_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn (self);
#line 550 "topbar.c"
}


static void _boxes_topbar_update_select_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn (self);
#line 557 "topbar.c"
}


static void __lambda147_ (BoxesTopbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_app_set_selection_mode (_tmp0_, FALSE);
#line 567 "topbar.c"
}


static void ___lambda147__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	__lambda147_ (self);
#line 574 "topbar.c"
}


static void _boxes_topbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_search_btn (self);
#line 581 "topbar.c"
}


static void _boxes_topbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_search_btn (self);
#line 588 "topbar.c"
}


static void boxes_topbar_setup_topbar (BoxesTopbar* self) {
	GtkNotebook* _tmp0_ = NULL;
	GtkBox* hbox = NULL;
	GtkBox* _tmp1_ = NULL;
	GtkNotebook* _tmp2_ = NULL;
	GtkBox* _tmp3_ = NULL;
	GtkHeaderBar* toolbar = NULL;
	GtkHeaderBar* _tmp4_ = NULL;
	GtkHeaderBar* _tmp5_ = NULL;
	GtkStyleContext* _tmp6_ = NULL;
	GtkHeaderBar* _tmp7_ = NULL;
	GtkHeaderBar* _tmp8_ = NULL;
	GtkHeaderBar* _tmp9_ = NULL;
	GtkStyleContext* _tmp10_ = NULL;
	GtkHeaderBar* _tmp11_ = NULL;
	GtkBox* _tmp12_ = NULL;
	GtkHeaderBar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	GtkButton* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	GtkButton* _tmp17_ = NULL;
	GtkStyleContext* _tmp18_ = NULL;
	GtkHeaderBar* _tmp19_ = NULL;
	GtkButton* _tmp20_ = NULL;
	GtkButton* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	GtkHeaderBar* _tmp23_ = NULL;
	GtkTextDirection _tmp24_ = 0;
	gchar* back_icon = NULL;
	const gchar* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	GtkImage* back_image = NULL;
	GtkImage* _tmp27_ = NULL;
	GtkButton* _tmp28_ = NULL;
	GtkButton* _tmp29_ = NULL;
	GtkButton* _tmp30_ = NULL;
	GtkButton* _tmp31_ = NULL;
	GtkStyleContext* _tmp32_ = NULL;
	GtkHeaderBar* _tmp33_ = NULL;
	GtkButton* _tmp34_ = NULL;
	GtkButton* _tmp35_ = NULL;
	AtkObject* _tmp36_ = NULL;
	const gchar* _tmp37_ = NULL;
	GtkButton* _tmp38_ = NULL;
	GtkSizeGroup* spinner_sizegroup = NULL;
	GtkSizeGroup* _tmp39_ = NULL;
	GtkSpinner* _tmp40_ = NULL;
	GtkSpinner* _tmp41_ = NULL;
	GtkSpinner* _tmp42_ = NULL;
	GtkSpinner* _tmp43_ = NULL;
	GtkSpinner* _tmp44_ = NULL;
	GtkHeaderBar* _tmp45_ = NULL;
	GtkSpinner* _tmp46_ = NULL;
	GtkSpinner* _tmp47_ = NULL;
	GtkImage* search_image = NULL;
	GtkImage* _tmp48_ = NULL;
	GtkToggleButton* _tmp49_ = NULL;
	GtkButton* _tmp50_ = NULL;
	GtkImage* _tmp51_ = NULL;
	GtkButton* _tmp52_ = NULL;
	GtkButton* _tmp53_ = NULL;
	GtkStyleContext* _tmp54_ = NULL;
	GtkHeaderBar* _tmp55_ = NULL;
	GtkButton* _tmp56_ = NULL;
	GtkButton* _tmp57_ = NULL;
	AtkObject* _tmp58_ = NULL;
	const gchar* _tmp59_ = NULL;
	GtkButton* _tmp60_ = NULL;
	BoxesApp* _tmp61_ = NULL;
	BoxesSearchbar* _tmp62_ = NULL;
	GtkImage* select_image = NULL;
	GtkImage* _tmp63_ = NULL;
	GtkButton* _tmp64_ = NULL;
	GtkButton* _tmp65_ = NULL;
	GtkButton* _tmp66_ = NULL;
	GtkButton* _tmp67_ = NULL;
	GtkStyleContext* _tmp68_ = NULL;
	GtkHeaderBar* _tmp69_ = NULL;
	GtkButton* _tmp70_ = NULL;
	GtkButton* _tmp71_ = NULL;
	AtkObject* _tmp72_ = NULL;
	const gchar* _tmp73_ = NULL;
	GtkButton* _tmp74_ = NULL;
	GtkButton* _tmp75_ = NULL;
	BoxesApp* _tmp76_ = NULL;
	BoxesApp* _tmp77_ = NULL;
	BoxesCollection* _tmp78_ = NULL;
	BoxesApp* _tmp79_ = NULL;
	BoxesCollection* _tmp80_ = NULL;
	GtkBox* _tmp81_ = NULL;
	GtkNotebook* _tmp82_ = NULL;
	GtkBox* _tmp83_ = NULL;
	GtkHeaderBar* _tmp84_ = NULL;
	GtkHeaderBar* _tmp85_ = NULL;
	GtkStyleContext* _tmp86_ = NULL;
	GtkHeaderBar* _tmp87_ = NULL;
	GtkStyleContext* _tmp88_ = NULL;
	GtkHeaderBar* _tmp89_ = NULL;
	GtkStyleContext* _tmp90_ = NULL;
	GMenu* menu = NULL;
	GMenu* _tmp91_ = NULL;
	const gchar* _tmp92_ = NULL;
	const gchar* _tmp93_ = NULL;
	const gchar* _tmp94_ = NULL;
	GtkMenuButton* _tmp95_ = NULL;
	GtkMenuButton* _tmp96_ = NULL;
	GtkMenuButton* _tmp97_ = NULL;
	GtkHeaderBar* _tmp98_ = NULL;
	GtkMenuButton* _tmp99_ = NULL;
	GtkBox* _tmp100_ = NULL;
	GtkHeaderBar* _tmp101_ = NULL;
	GtkImage* _tmp102_ = NULL;
	GtkToggleButton* _tmp103_ = NULL;
	GtkButton* _tmp104_ = NULL;
	GtkImage* _tmp105_ = NULL;
	GtkButton* _tmp106_ = NULL;
	GtkButton* _tmp107_ = NULL;
	GtkStyleContext* _tmp108_ = NULL;
	GtkHeaderBar* _tmp109_ = NULL;
	GtkButton* _tmp110_ = NULL;
	GtkButton* _tmp111_ = NULL;
	BoxesApp* _tmp112_ = NULL;
	BoxesSearchbar* _tmp113_ = NULL;
	const gchar* _tmp114_ = NULL;
	GtkButton* _tmp115_ = NULL;
	GtkButton* _tmp116_ = NULL;
	GtkButton* _tmp117_ = NULL;
	GtkStyleContext* _tmp118_ = NULL;
	GtkHeaderBar* _tmp119_ = NULL;
	GtkButton* _tmp120_ = NULL;
	GtkButton* _tmp121_ = NULL;
	GtkBox* _tmp122_ = NULL;
	GtkNotebook* _tmp123_ = NULL;
	GtkBox* _tmp124_ = NULL;
	GtkBox* _tmp125_ = NULL;
	GtkNotebook* _tmp126_ = NULL;
	GtkBox* _tmp127_ = NULL;
	GtkBox* _tmp128_ = NULL;
	BoxesApp* _tmp129_ = NULL;
	BoxesDisplayPage* _tmp130_ = NULL;
	BoxesDisplayToolbar* _tmp131_ = NULL;
	GtkHeaderBar* _tmp132_ = NULL;
	GtkBox* _tmp133_ = NULL;
	GtkHeaderBar* _tmp134_ = NULL;
	GtkNotebook* _tmp135_ = NULL;
	GtkBox* _tmp136_ = NULL;
	BoxesApp* _tmp137_ = NULL;
	BoxesCollection* _tmp138_ = NULL;
	BoxesApp* _tmp139_ = NULL;
	BoxesCollection* _tmp140_ = NULL;
	GtkNotebook* _tmp141_ = NULL;
	GtkNotebook* _tmp142_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = (GtkNotebook*) gtk_notebook_new ();
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp0_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->notebook);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->notebook = _tmp0_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp1_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	hbox = _tmp1_;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = self->notebook;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = hbox;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp2_, (GtkWidget*) _tmp3_, NULL);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = (GtkHeaderBar*) gtk_header_bar_new ();
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp4_);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	toolbar = _tmp4_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = toolbar;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = gtk_widget_get_style_context ((GtkWidget*) _tmp5_);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp6_, "titlebar");
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp7_ = toolbar;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->collection_toolbar);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->collection_toolbar = _tmp8_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp9_ = toolbar;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp10_ = gtk_widget_get_style_context ((GtkWidget*) _tmp9_);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp10_, GTK_STYLE_CLASS_MENUBAR);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp11_ = toolbar;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_show_close_button (_tmp11_, TRUE);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp12_ = hbox;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp13_ = toolbar;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_box_pack_start (_tmp12_, (GtkWidget*) _tmp13_, TRUE, TRUE, (guint) 0);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp14_ = _ ("_New");
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp15_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp14_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp15_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->new_btn);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->new_btn = _tmp15_;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp16_ = self->priv->new_btn;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp16_, GTK_ALIGN_CENTER);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp17_ = self->priv->new_btn;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp18_ = gtk_widget_get_style_context ((GtkWidget*) _tmp17_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp18_, "text-button");
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp19_ = toolbar;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp20_ = self->priv->new_btn;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_pack_start (_tmp19_, (GtkWidget*) _tmp20_);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp21_ = self->priv->new_btn;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp21_, "clicked", (GCallback) ___lambda28__gtk_button_clicked, self, 0);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp23_ = toolbar;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp24_ = gtk_widget_get_direction ((GtkWidget*) _tmp23_);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp24_ == GTK_TEXT_DIR_RTL) {
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp22_ = "go-previous-rtl-symbolic";
#line 840 "topbar.c"
	} else {
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp22_ = "go-previous-symbolic";
#line 844 "topbar.c"
	}
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp25_ = _tmp22_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp26_ = g_strdup (_tmp25_);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	back_icon = _tmp26_;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp27_ = (GtkImage*) gtk_image_new_from_icon_name (back_icon, GTK_ICON_SIZE_MENU);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp27_);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	back_image = _tmp27_;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp28_ = (GtkButton*) gtk_button_new ();
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp28_);
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->back_btn);
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->back_btn = _tmp28_;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp29_ = self->priv->back_btn;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_button_set_image (_tmp29_, (GtkWidget*) back_image);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp30_ = self->priv->back_btn;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp30_, GTK_ALIGN_CENTER);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp31_ = self->priv->back_btn;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp32_ = gtk_widget_get_style_context ((GtkWidget*) _tmp31_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp32_, "image-button");
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp33_ = toolbar;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp34_ = self->priv->back_btn;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_pack_start (_tmp33_, (GtkWidget*) _tmp34_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp35_ = self->priv->back_btn;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp36_ = gtk_widget_get_accessible ((GtkWidget*) _tmp35_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp37_ = _ ("Back");
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	atk_object_set_name (_tmp36_, _tmp37_);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp38_ = self->priv->back_btn;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp38_, "clicked", (GCallback) ___lambda29__gtk_button_clicked, self, 0);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp39_ = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	spinner_sizegroup = _tmp39_;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp40_ = (GtkSpinner*) gtk_spinner_new ();
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp40_);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->spinner);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->spinner = _tmp40_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp41_ = self->priv->spinner;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_spinner_start (_tmp41_);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp42_ = self->priv->spinner;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp42_, TRUE);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp43_ = self->priv->spinner;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp43_, TRUE);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp44_ = self->priv->spinner;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_set ((GtkWidget*) _tmp44_, "margin", 6, NULL);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp45_ = toolbar;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp46_ = self->priv->spinner;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_pack_end (_tmp45_, (GtkWidget*) _tmp46_);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp47_ = self->priv->spinner;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_size_group_add_widget (spinner_sizegroup, (GtkWidget*) _tmp47_);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp48_ = (GtkImage*) gtk_image_new_from_icon_name ("edit-find-symbolic", GTK_ICON_SIZE_MENU);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp48_);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	search_image = _tmp48_;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp49_ = (GtkToggleButton*) gtk_toggle_button_new ();
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp49_);
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->search_btn);
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->search_btn = (GtkButton*) _tmp49_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp50_ = self->priv->search_btn;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp51_ = search_image;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_button_set_image (_tmp50_, (GtkWidget*) _tmp51_);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp52_ = self->priv->search_btn;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp52_, GTK_ALIGN_CENTER);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp53_ = self->priv->search_btn;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp54_ = gtk_widget_get_style_context ((GtkWidget*) _tmp53_);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp54_, "image-button");
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp55_ = toolbar;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp56_ = self->priv->search_btn;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_pack_end (_tmp55_, (GtkWidget*) _tmp56_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp57_ = self->priv->search_btn;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp58_ = gtk_widget_get_accessible ((GtkWidget*) _tmp57_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp59_ = _ ("Search");
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	atk_object_set_name (_tmp58_, _tmp59_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp60_ = self->priv->search_btn;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp61_ = boxes_app_app;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp62_ = _tmp61_->searchbar;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp60_, "active", (GObject*) _tmp62_, "visible", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp63_ = (GtkImage*) gtk_image_new_from_icon_name ("object-select-symbolic", GTK_ICON_SIZE_MENU);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp63_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	select_image = _tmp63_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp64_ = (GtkButton*) gtk_button_new ();
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp64_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->select_btn);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->select_btn = _tmp64_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp65_ = self->priv->select_btn;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_button_set_image (_tmp65_, (GtkWidget*) select_image);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp66_ = self->priv->select_btn;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp66_, GTK_ALIGN_CENTER);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp67_ = self->priv->select_btn;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp68_ = gtk_widget_get_style_context ((GtkWidget*) _tmp67_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp68_, "image-button");
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp69_ = toolbar;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp70_ = self->priv->select_btn;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_pack_end (_tmp69_, (GtkWidget*) _tmp70_);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp71_ = self->priv->select_btn;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp72_ = gtk_widget_get_accessible ((GtkWidget*) _tmp71_);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp73_ = _ ("Select Items");
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	atk_object_set_name (_tmp72_, _tmp73_);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp74_ = self->priv->select_btn;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_size_group_add_widget (spinner_sizegroup, (GtkWidget*) _tmp74_);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp75_ = self->priv->select_btn;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp75_, "clicked", (GCallback) ___lambda145__gtk_button_clicked, self, 0);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp76_ = boxes_app_app;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) _tmp76_, "notify::selection-mode", (GCallback) ___lambda146__g_object_notify, self, 0);
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn (self);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp77_ = boxes_app_app;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp78_ = _tmp77_->collection;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp78_, "item-added", (GCallback) _boxes_topbar_update_select_btn_boxes_collection_item_added, self, 0);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp79_ = boxes_app_app;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp80_ = _tmp79_->collection;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp80_, "item-removed", (GCallback) _boxes_topbar_update_select_btn_boxes_collection_item_removed, self, 0);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp81_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp81_);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	hbox = _tmp81_;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp82_ = self->notebook;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp83_ = hbox;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp82_, (GtkWidget*) _tmp83_, NULL);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp84_ = (GtkHeaderBar*) gtk_header_bar_new ();
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp84_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_toolbar);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->selection_toolbar = _tmp84_;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp85_ = self->priv->selection_toolbar;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp86_ = gtk_widget_get_style_context ((GtkWidget*) _tmp85_);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp86_, "selection-mode");
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp87_ = self->priv->selection_toolbar;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp88_ = gtk_widget_get_style_context ((GtkWidget*) _tmp87_);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp88_, GTK_STYLE_CLASS_MENUBAR);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp89_ = self->priv->selection_toolbar;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp90_ = gtk_widget_get_style_context ((GtkWidget*) _tmp89_);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp90_, "titlebar");
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp91_ = g_menu_new ();
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	menu = _tmp91_;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp92_ = _ ("Select All");
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_menu_append (menu, _tmp92_, "app.select-all");
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp93_ = _ ("Select Running");
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_menu_append (menu, _tmp93_, "app.select-running");
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp94_ = _ ("Select None");
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_menu_append (menu, _tmp94_, "app.select-none");
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp95_ = (GtkMenuButton*) gtk_menu_button_new ();
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp95_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_menu_button);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->selection_menu_button = _tmp95_;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp96_ = self->priv->selection_menu_button;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp96_, GTK_ALIGN_CENTER);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp97_ = self->priv->selection_menu_button;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_menu_button_set_menu_model (_tmp97_, (GMenuModel*) menu);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp98_ = self->priv->selection_toolbar;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp99_ = self->priv->selection_menu_button;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_custom_title (_tmp98_, (GtkWidget*) _tmp99_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp100_ = hbox;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp101_ = self->priv->selection_toolbar;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_box_pack_start (_tmp100_, (GtkWidget*) _tmp101_, TRUE, TRUE, (guint) 0);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_selection_label (self);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp102_ = (GtkImage*) gtk_image_new_from_icon_name ("edit-find-symbolic", GTK_ICON_SIZE_MENU);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp102_);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (search_image);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	search_image = _tmp102_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp103_ = (GtkToggleButton*) gtk_toggle_button_new ();
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp103_);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->search2_btn);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->search2_btn = (GtkButton*) _tmp103_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp104_ = self->priv->search2_btn;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp105_ = search_image;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_button_set_image (_tmp104_, (GtkWidget*) _tmp105_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp106_ = self->priv->search2_btn;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp106_, GTK_ALIGN_CENTER);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp107_ = self->priv->search2_btn;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp108_ = gtk_widget_get_style_context ((GtkWidget*) _tmp107_);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp108_, "image-button");
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp109_ = self->priv->selection_toolbar;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp110_ = self->priv->search2_btn;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_pack_end (_tmp109_, (GtkWidget*) _tmp110_);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp111_ = self->priv->search2_btn;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp112_ = boxes_app_app;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp113_ = _tmp112_->searchbar;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp111_, "active", (GObject*) _tmp113_, "visible", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp114_ = _ ("_Cancel");
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp115_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp114_);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp115_);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->cancel_btn);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->cancel_btn = _tmp115_;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp116_ = self->priv->cancel_btn;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp116_, GTK_ALIGN_CENTER);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp117_ = self->priv->cancel_btn;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp118_ = gtk_widget_get_style_context ((GtkWidget*) _tmp117_);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp118_, "text-button");
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp119_ = self->priv->selection_toolbar;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp120_ = self->priv->cancel_btn;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_pack_end (_tmp119_, (GtkWidget*) _tmp120_);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp121_ = self->priv->cancel_btn;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp121_, "clicked", (GCallback) ___lambda147__gtk_button_clicked, self, 0);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp122_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp122_);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	hbox = _tmp122_;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp123_ = self->notebook;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp124_ = hbox;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp123_, (GtkWidget*) _tmp124_, NULL);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp125_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp125_);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	hbox = _tmp125_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp126_ = self->notebook;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp127_ = hbox;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp126_, (GtkWidget*) _tmp127_, NULL);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp128_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp128_);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	hbox = _tmp128_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp129_ = boxes_app_app;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp130_ = _tmp129_->display_page;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp131_ = _tmp130_->title_toolbar;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp132_ = _g_object_ref0 ((GtkHeaderBar*) _tmp131_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->display_toolbar);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv->display_toolbar = _tmp132_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp133_ = hbox;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp134_ = self->priv->display_toolbar;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_box_pack_start (_tmp133_, (GtkWidget*) _tmp134_, TRUE, TRUE, (guint) 0);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp135_ = self->notebook;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp136_ = hbox;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp135_, (GtkWidget*) _tmp136_, NULL);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_search_btn (self);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp137_ = boxes_app_app;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp138_ = _tmp137_->collection;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp138_, "item-added", (GCallback) _boxes_topbar_update_search_btn_boxes_collection_item_added, self, 0);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp139_ = boxes_app_app;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp140_ = _tmp139_->collection;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp140_, "item-removed", (GCallback) _boxes_topbar_update_search_btn_boxes_collection_item_removed, self, 0);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp141_ = self->notebook;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_notebook_set_show_tabs (_tmp141_, FALSE);
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp142_ = self->notebook;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp142_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (menu);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (select_image);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (search_image);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (spinner_sizegroup);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (back_image);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_free0 (back_icon);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (toolbar);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 1316 "topbar.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4239 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4239 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4239 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4239 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	return result;
#line 1331 "topbar.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4240 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4240 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4240 "/home/zeenix/jhbuild/share/vala-0.24/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 1343 "topbar.c"
}


static void boxes_topbar_update_search_btn (BoxesTopbar* self) {
	GtkButton* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GtkButton* _tmp6_ = NULL;
	BoxesApp* _tmp7_ = NULL;
	BoxesCollection* _tmp8_ = NULL;
	GPtrArray* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->search_btn;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_->items;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = self->priv->search2_btn;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp7_ = boxes_app_app;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp8_ = _tmp7_->collection;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp9_ = _tmp8_->items;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp10_ = g_ptr_array_get_length (_tmp9_);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp11_ = _tmp10_;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, _tmp11_ != 0);
#line 1390 "topbar.c"
}


static void boxes_topbar_update_select_btn (BoxesTopbar* self) {
	GtkButton* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->select_btn;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_->items;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 1417 "topbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1424 "topbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_list_free (self);
#line 1433 "topbar.c"
}


static void boxes_topbar_update_selection_label (BoxesTopbar* self) {
	guint items = 0U;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	guint _tmp5_ = 0U;
	guint _tmp6_ = 0U;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	items = _tmp5_;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp6_ = items;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp6_ > ((guint) 0)) {
#line 1468 "topbar.c"
		GtkMenuButton* _tmp7_ = NULL;
		guint _tmp8_ = 0U;
		const gchar* _tmp9_ = NULL;
		guint _tmp10_ = 0U;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp7_ = self->priv->selection_menu_button;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp8_ = items;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp9_ = ngettext ("%d selected", "%d selected", (gulong) _tmp8_);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp10_ = items;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp11_ = g_strdup_printf (_tmp9_, _tmp10_);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp12_ = _tmp11_;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		gtk_button_set_label ((GtkButton*) _tmp7_, _tmp12_);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_g_free0 (_tmp12_);
#line 1491 "topbar.c"
	} else {
		GtkMenuButton* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp13_ = self->priv->selection_menu_button;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp14_ = _ ("(Click on items to select them)");
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		gtk_button_set_label ((GtkButton*) _tmp13_, _tmp14_);
#line 1501 "topbar.c"
	}
}


static void boxes_topbar_real_ui_state_changed (BoxesUI* base) {
	BoxesTopbar * self;
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = _tmp0_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (_tmp1_) {
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 1520 "topbar.c"
		{
			GtkNotebook* _tmp2_ = NULL;
			GtkButton* _tmp3_ = NULL;
			GtkSpinner* _tmp4_ = NULL;
			GtkButton* _tmp5_ = NULL;
			GtkButton* _tmp6_ = NULL;
			GtkButton* _tmp7_ = NULL;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp2_ = self->notebook;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp2_, "page", (gint) BOXES_TOPBAR_PAGE_COLLECTION, NULL);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp3_ = self->priv->back_btn;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp3_);
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp4_ = self->priv->spinner;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp4_);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp5_ = self->priv->select_btn;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp5_);
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp6_ = self->priv->search_btn;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp6_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp7_ = self->priv->new_btn;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp7_);
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1554 "topbar.c"
		}
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_CREDS:
#line 1558 "topbar.c"
		{
			GtkNotebook* _tmp8_ = NULL;
			GtkButton* _tmp9_ = NULL;
			GtkButton* _tmp10_ = NULL;
			GtkSpinner* _tmp11_ = NULL;
			GtkButton* _tmp12_ = NULL;
			GtkButton* _tmp13_ = NULL;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp8_ = self->notebook;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp8_, "page", (gint) BOXES_TOPBAR_PAGE_COLLECTION, NULL);
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp9_ = self->priv->new_btn;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp9_);
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp10_ = self->priv->back_btn;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp10_);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp11_ = self->priv->spinner;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp11_);
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp12_ = self->priv->select_btn;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp12_);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp13_ = self->priv->search_btn;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp13_);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1592 "topbar.c"
		}
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 1596 "topbar.c"
		{
			GtkNotebook* _tmp14_ = NULL;
			GtkSpinner* _tmp15_ = NULL;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp14_ = self->notebook;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp14_, "page", (gint) BOXES_TOPBAR_PAGE_DISPLAY, NULL);
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp15_ = self->priv->spinner;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp15_);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1610 "topbar.c"
		}
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 1614 "topbar.c"
		{
			GtkNotebook* _tmp16_ = NULL;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp16_ = self->notebook;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp16_, "page", (gint) BOXES_TOPBAR_PAGE_PROPERTIES, NULL);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1623 "topbar.c"
		}
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 1627 "topbar.c"
		{
			GtkNotebook* _tmp17_ = NULL;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			_tmp17_ = self->notebook;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp17_, "page", (gint) BOXES_TOPBAR_PAGE_WIZARD, NULL);
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1636 "topbar.c"
		}
		default:
		{
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
			break;
#line 1642 "topbar.c"
		}
	}
}


static ClutterActor* boxes_topbar_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesTopbar* self;
	ClutterActor* _tmp0_ = NULL;
	ClutterActor* _tmp2_ = NULL;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	if (_tmp0_ == NULL) {
#line 1659 "topbar.c"
		ClutterActor* _tmp1_ = NULL;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_tmp1_ = clutter_actor_new ();
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_object_ref_sink (_tmp1_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		_g_object_unref0 (self->priv->gtk_actor);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		self->priv->gtk_actor = _tmp1_;
#line 1669 "topbar.c"
	}
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = self->priv->gtk_actor;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	result = _tmp2_;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	return result;
#line 1677 "topbar.c"
}


GtkWidget* boxes_topbar_get_widget (BoxesTopbar* self) {
	GtkWidget* result;
	GtkNotebook* _tmp0_ = NULL;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->notebook;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	result = (GtkWidget*) _tmp0_;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	return result;
#line 1692 "topbar.c"
}


const gchar* boxes_topbar_get_status (BoxesTopbar* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->_status;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	return result;
#line 1707 "topbar.c"
}


void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GtkHeaderBar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkHeaderBar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_free0 (self->_status);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->_status = _tmp1_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp2_ = self->priv->collection_toolbar;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp3_ = self->_status;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_title (_tmp2_, _tmp3_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp4_ = self->priv->display_toolbar;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_tmp5_ = self->_status;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_title (_tmp4_, _tmp5_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "status");
#line 1742 "topbar.c"
}


static void boxes_topbar_class_init (BoxesTopbarClass * klass) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	boxes_topbar_parent_class = g_type_class_peek_parent (klass);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesTopbarPrivate));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_topbar_real_ui_state_changed;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_topbar_real_get_actor;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_topbar_get_property;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_topbar_set_property;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_topbar_finalize;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_WIDGET, g_param_spec_object ("widget", "widget", "widget", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_STATUS, g_param_spec_string ("status", "status", "status", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1767 "topbar.c"
}


static void boxes_topbar_instance_init (BoxesTopbar * self) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self->priv = BOXES_TOPBAR_GET_PRIVATE (self);
#line 1774 "topbar.c"
}


static void boxes_topbar_finalize (GObject* obj) {
	BoxesTopbar * self;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->notebook);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->spinner);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->search_btn);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->search2_btn);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->select_btn);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->cancel_btn);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->back_btn);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->new_btn);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_menu_button);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_toolbar);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->collection_toolbar);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->display_toolbar);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	_g_free0 (self->_status);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (boxes_topbar_parent_class)->finalize (obj);
#line 1812 "topbar.c"
}


GType boxes_topbar_get_type (void) {
	static volatile gsize boxes_topbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesTopbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_topbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesTopbar), 0, (GInstanceInitFunc) boxes_topbar_instance_init, NULL };
		GType boxes_topbar_type_id;
		boxes_topbar_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesTopbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_topbar_type_id__volatile, boxes_topbar_type_id);
	}
	return boxes_topbar_type_id__volatile;
}


static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesTopbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (property_id) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_ACTOR:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_WIDGET:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_value_set_object (value, boxes_topbar_get_widget (self));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_STATUS:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		g_value_set_string (value, boxes_topbar_get_status (self));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1851 "topbar.c"
		default:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1857 "topbar.c"
	}
}


static void _vala_boxes_topbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesTopbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
	switch (property_id) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_STATUS:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_status (self, g_value_get_string (value));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1873 "topbar.c"
		default:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/topbar.vala"
		break;
#line 1879 "topbar.c"
	}
}



